Welcome to meshmode's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   mesh
   array
   discretization
   connection
   interop
   misc
   🚀 Github <https://github.com/inducer/meshmode>
   💾 Download Releases <https://pypi.org/project/meshmode>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

